# Khmer Names 🇰🇭

A Python library to generate random Khmer names.

## Installation

```bash
pip install khmernames
```

## Usage

```python
from khmernames import random_full_name, generate_unique_names

print(random_full_name())
print(generate_unique_names(10))
```
